#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/7/13 16:16
Desc: 新浪财经-股票-行业分类
http://vip.stock.finance.sina.com.cn/mkt/
"""

import math

import pandas as pd
import requests
from bs4 import BeautifulSoup
from tqdm import tqdm


def stock_classify_board() -> dict:
    """
    http://vip.stock.finance.sina.com.cn/mkt/
    :return: 股票分类字典
    :rtype: dict
    """
    url = "http://vip.stock.finance.sina.com.cn/quotes_service/api/json_v2.php/Market_Center.getHQNodes"
    r = requests.get(url)
    data_json = r.json()
    big_dict = {}
    class_name_list = [
        BeautifulSoup(item[0], "lxml").find("font").text
        if "font" in item[0]
        else item[0]
        for item in data_json[1][0][1]
    ]  # 沪深股市
    for num, class_name in enumerate(class_name_list):
        temp_df = pd.DataFrame([item for item in data_json[1][0][1][num][1:][0]])
        if temp_df.shape[1] == 5:
            temp_df.columns = ["name", "_", "code", "_", "_"]
            temp_df = temp_df[["name", "code"]]
        if temp_df.shape[1] == 4:
            temp_df.columns = ["name", "_", "code", "_"]
            temp_df = temp_df[["name", "code"]]
        if temp_df.shape[1] == 3:
            temp_df.columns = ["name", "_", "code"]
            temp_df = temp_df[["name", "code"]]
        big_dict.update({class_name: temp_df})
    return big_dict


def stock_classify_sina(symbol: str = "热门概念") -> pd.DataFrame:
    """
    按 symbol 分类后的股票
    http://vip.stock.finance.sina.com.cn/mkt/
    :param symbol: choice of {'申万行业', '申万二级', '热门概念', '地域板块'}
    :type symbol: str
    :return: 分类后的股票
    :rtype: pandas.DataFrame
    """
    stock_classify_board_dict = stock_classify_board()
    data_df = pd.DataFrame()
    for num in tqdm(range(len(stock_classify_board_dict[symbol]["code"])), leave=False):
        url = "http://vip.stock.finance.sina.com.cn/quotes_service/api/json_v2.php/Market_Center.getHQNodeStockCount"
        params = {"node": stock_classify_board_dict[symbol]["code"][num]}
        r = requests.get(url, params=params)
        page_num = math.ceil(int(r.json()) / 80)
        url = "http://vip.stock.finance.sina.com.cn/quotes_service/api/json_v2.php/Market_Center.getHQNodeData"
        big_df = pd.DataFrame()
        for page in range(1, page_num + 1):
            params = {
                "page": page,
                "num": "80",
                "sort": "symbol",
                "asc": "1",
                "node": stock_classify_board_dict[symbol]["code"][num],
                "symbol": "",
                "_s_r_a": "init",
            }
            r = requests.get(url, params=params)
            data_json = r.json()
            temp_df = pd.DataFrame(data_json)
            big_df = pd.concat([big_df, temp_df], ignore_index=True)
            big_df["class"] = stock_classify_board_dict[symbol]["name"][num]
        data_df = pd.concat([data_df, big_df], ignore_index=True)
    return data_df


if __name__ == "__main__":
    stock_classify_sina_df = stock_classify_sina(symbol="热门概念")
    print(stock_classify_sina_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/2/28 13:00
Desc: 东方财富网-数据中心-研究报告-个股研报
https://data.eastmoney.com/report/stock.jshtml
"""

import datetime
import pandas as pd
import requests

from akshare.utils.tqdm import get_tqdm


def stock_research_report_em(symbol: str = "000001") -> pd.DataFrame:
    """
    东方财富网-数据中心-研究报告-个股研报
    https://data.eastmoney.com/report/stock.jshtml
    :param symbol: 个股代码
    :type symbol: str
    :return: 个股研报
    :rtype: pandas.DataFrame
    """
    url = "https://reportapi.eastmoney.com/report/list"
    params = {
        "industryCode": "*",
        "pageSize": "5000",
        "industry": "*",
        "rating": "*",
        "ratingChange": "*",
        "beginTime": "2000-01-01",
        "endTime": f"{datetime.datetime.now().year + 1}-01-01",
        "pageNo": "1",
        "fields": "",
        "qType": "0",
        "orgCode": "",
        "code": symbol,
        "rcode": "",
        "p": "1",
        "pageNum": "1",
        "pageNumber": "1",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json["TotalPage"]
    current_year = data_json["currentYear"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update(
            {
                "pageNo": page,
                "p": page,
                "pageNum": page,
                "pageNumber": page,
            }
        )
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        big_df = pd.concat(objs=[big_df, temp_df], axis=0, ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df["index"] = big_df["index"] + 1
    predict_this_year_eps_title = f"{current_year}-盈利预测-收益"
    predict_this_year_pe_title = f"{current_year}-盈利预测-市盈率"
    predict_next_year_eps_title = f"{current_year + 1}-盈利预测-收益"
    predict_next_year_pe_title = f"{current_year + 1}-盈利预测-市盈率"
    predict_next_two_year_eps_title = f"{current_year + 2}-盈利预测-收益"
    predict_next_two_year_pe_title = f"{current_year + 2}-盈利预测-市盈率"
    big_df["pdfUrl"] = big_df["infoCode"].apply(
        lambda x: f"https://pdf.dfcfw.com/pdf/H3_{x}_1.pdf"
    )
    big_df.rename(
        columns={
            "index": "序号",
            "title": "报告名称",
            "stockName": "股票简称",
            "stockCode": "股票代码",
            "orgCode": "-",
            "orgName": "-",
            "orgSName": "机构",
            "publishDate": "日期",
            "infoCode": "-",
            "column": "-",
            "predictNextTwoYearEps": predict_next_two_year_eps_title,
            "predictNextTwoYearPe": predict_next_two_year_pe_title,
            "predictNextYearEps": predict_next_year_eps_title,
            "predictNextYearPe": predict_next_year_pe_title,
            "predictThisYearEps": predict_this_year_eps_title,
            "predictThisYearPe": predict_this_year_pe_title,
            "predictLastYearEps": "-",
            "predictLastYearPe": "-",
            "actualLastTwoYearEps": "-",
            "actualLastYearEps": "-",
            "industryCode": "-",
            "industryName": "-",
            "emIndustryCode": "-",
            "indvInduCode": "-",
            "indvInduName": "行业",
            "emRatingCode": "-",
            "emRatingValue": "-",
            "emRatingName": "东财评级",
            "lastEmRatingCode": "-",
            "lastEmRatingValue": "-",
            "lastEmRatingName": "-",
            "ratingChange": "-",
            "reportType": "-",
            "author": "-",
            "indvIsNew": "-",
            "researcher": "-",
            "newListingDate": "-",
            "newPurchaseDate": "-",
            "newIssuePrice": "-",
            "newPeIssueA": "-",
            "indvAimPriceT": "-",
            "indvAimPriceL": "-",
            "attachType": "-",
            "attachSize": "-",
            "attachPages": "-",
            "encodeUrl": "-",
            "sRatingName": "-",
            "sRatingCode": "-",
            "market": "-",
            "authorID": "-",
            "count": "近一月个股研报数",
            "orgType": "-",
            "pdfUrl": "报告PDF链接",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "序号",
            "股票代码",
            "股票简称",
            "报告名称",
            "东财评级",
            "机构",
            "近一月个股研报数",
            predict_this_year_eps_title,
            predict_this_year_pe_title,
            predict_next_year_eps_title,
            predict_next_year_pe_title,
            predict_next_two_year_eps_title,
            predict_next_two_year_pe_title,
            "行业",
            "日期",
            "报告PDF链接",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"], errors="coerce").dt.date
    big_df["近一月个股研报数"] = pd.to_numeric(
        big_df["近一月个股研报数"], errors="coerce"
    )
    big_df[predict_this_year_eps_title] = pd.to_numeric(
        big_df[predict_this_year_eps_title], errors="coerce"
    )
    big_df[predict_this_year_pe_title] = pd.to_numeric(
        big_df[predict_this_year_pe_title], errors="coerce"
    )
    big_df[predict_next_year_eps_title] = pd.to_numeric(
        big_df[predict_next_year_eps_title], errors="coerce"
    )
    big_df[predict_next_year_pe_title] = pd.to_numeric(
        big_df[predict_next_year_pe_title], errors="coerce"
    )
    big_df[predict_next_two_year_eps_title] = pd.to_numeric(
        big_df[predict_next_two_year_eps_title], errors="coerce"
    )
    big_df[predict_next_two_year_pe_title] = pd.to_numeric(
        big_df[predict_next_two_year_pe_title], errors="coerce"
    )
    return big_df


if __name__ == "__main__":
    stock_research_report_em_df = stock_research_report_em(symbol="000001")
    print(stock_research_report_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/3/18 14:00
Desc: 玄田数据
https://zhujia.zhuwang.com.cn
"""

import pandas as pd
import requests


def futures_hog_core(symbol: str = "外三元") -> pd.DataFrame:
    """
    玄田数据-核心数据
    https://zhujia.zhuwang.com.cn
    :param symbol: choice of {"外三元", "内三元", "土杂猪"}
    :type symbol: str
    :return: 玄田数据-核心数据
    :rtype: pandas.DataFrame
    """
    if symbol == "外三元":
        url = "https://xt.yangzhu.vip/data/getzhujiahitsdata"
        params = {"ptype": "1", "areano": "-1", "datetype": "0"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["value", "date"]
        temp_df = temp_df[["date", "value"]]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "内三元":
        url = "https://xt.yangzhu.vip/data/getzhujiahitsdata"
        params = {"ptype": "2", "areano": "-1", "datetype": "0"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["value", "date"]
        temp_df = temp_df[["date", "value"]]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "土杂猪":
        url = "https://xt.yangzhu.vip/data/getzhujiahitsdata"
        params = {"ptype": "3", "areano": "-1", "datetype": "0"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["value", "date"]
        temp_df = temp_df[["date", "value"]]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df


def futures_hog_cost(symbol: str = "玉米") -> pd.DataFrame:
    """
    玄田数据-成本维度
    https://zhujia.zhuwang.com.cn
    :param symbol: choice of {"玉米", "豆粕", "二元母猪价格", "仔猪价格"}
    :type symbol: str
    :return: 玄田数据-成本维度
    :rtype: pandas.DataFrame
    """
    if symbol == "玉米":
        url = "https://xt.yangzhu.vip/data/getzhujiahitsdata"
        params = {"ptype": "4", "areano": "-1", "datetype": "0"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["value", "date"]
        temp_df = temp_df[["date", "value"]]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "豆粕":
        url = "https://xt.yangzhu.vip/data/getzhujiahitsdata"
        params = {"ptype": "5", "areano": "-1", "datetype": "0"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["value", "date"]
        temp_df = temp_df[["date", "value"]]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "二元母猪价格":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {
            "ptype": "1",
            "areano": "-1",
        }
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["date", "value"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "仔猪价格":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {
            "ptype": "2",
            "areano": "-1",
        }
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["date", "value"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df


def futures_hog_supply(symbol: str = "猪肉批发价") -> pd.DataFrame:
    """
    玄田数据-供应维度
    https://zhujia.zhuwang.com.cn
    :param symbol: choice of {"猪肉批发价", "储备冻猪肉", "饲料原料数据", "白条肉",
    "生猪产能", "育肥猪", "肉类价格指数", "猪粮比价"}
    :type symbol: str
    :return: 玄田数据-供应维度
    :rtype: pandas.DataFrame
    """
    if symbol == "猪肉批发价":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "3", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["date", "item", "value"]
        del temp_df["item"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "储备冻猪肉":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "4", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["date", "value"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "饲料原料数据":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "5", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = [
            "周期",
            "大豆进口金额",
            "大豆播种面积",
            "玉米进口金额",
            "玉米播种面积",
        ]
        temp_df["周期"] = temp_df["周期"].astype(int).astype(str)
        temp_df["大豆进口金额"] = pd.to_numeric(
            temp_df["大豆进口金额"], errors="coerce"
        )
        temp_df["大豆播种面积"] = pd.to_numeric(
            temp_df["大豆播种面积"], errors="coerce"
        )
        temp_df["玉米进口金额"] = pd.to_numeric(
            temp_df["玉米进口金额"], errors="coerce"
        )
        temp_df["玉米播种面积"] = pd.to_numeric(
            temp_df["玉米播种面积"], errors="coerce"
        )
        return temp_df
    elif symbol == "白条肉":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "6", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["周期", "白条肉平均出厂价格", "环比", "同比"]
        temp_df["白条肉平均出厂价格"] = pd.to_numeric(
            temp_df["白条肉平均出厂价格"], errors="coerce"
        )
        temp_df["环比"] = pd.to_numeric(temp_df["环比"], errors="coerce")
        temp_df["同比"] = pd.to_numeric(temp_df["同比"], errors="coerce")
        return temp_df
    elif symbol == "生猪产能":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "7", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["周期", "能繁母猪存栏", "猪肉产量", "生猪存栏", "生猪出栏"]
        temp_df["能繁母猪存栏"] = pd.to_numeric(
            temp_df["能繁母猪存栏"], errors="coerce"
        )
        temp_df["猪肉产量"] = pd.to_numeric(temp_df["猪肉产量"], errors="coerce")
        temp_df["生猪存栏"] = pd.to_numeric(temp_df["生猪存栏"], errors="coerce")
        temp_df["生猪出栏"] = pd.to_numeric(temp_df["生猪出栏"], errors="coerce")
        return temp_df
    elif symbol == "育肥猪":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "9", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df = temp_df[["date", "benzhou"]]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["benzhou"] = pd.to_numeric(temp_df["benzhou"], errors="coerce")
        return temp_df
    elif symbol == "肉类价格指数":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "10", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["date", "item", "value"]
        del temp_df["item"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df
    elif symbol == "猪粮比价":
        url = "https://xt.yangzhu.vip/data/getmapdata"
        params = {"ptype": "11", "areano": "-1"}
        r = requests.post(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = ["date", "value"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
        return temp_df


if __name__ == "__main__":
    futures_hog_core_df = futures_hog_core(symbol="外三元")
    print(futures_hog_core_df)

    futures_hog_core_df = futures_hog_core(symbol="内三元")
    print(futures_hog_core_df)

    futures_hog_core_df = futures_hog_core(symbol="土杂猪")
    print(futures_hog_core_df)

    futures_hog_cost_df = futures_hog_cost(symbol="玉米")
    print(futures_hog_cost_df)

    futures_hog_cost_df = futures_hog_cost(symbol="豆粕")
    print(futures_hog_cost_df)

    futures_hog_cost_df = futures_hog_cost(symbol="二元母猪价格")
    print(futures_hog_cost_df)

    futures_hog_cost_df = futures_hog_cost(symbol="仔猪价格")
    print(futures_hog_cost_df)

    futures_hog_supply_df = futures_hog_supply(symbol="猪肉批发价")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="储备冻猪肉")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="饲料原料数据")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="白条肉")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="生猪产能")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="育肥猪")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="肉类价格指数")
    print(futures_hog_supply_df)

    futures_hog_supply_df = futures_hog_supply(symbol="猪粮比价")
    print(futures_hog_supply_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/1/20 22:00
Desc: 经济政策不确定性指数
https://www.policyuncertainty.com/index.html
"""

import pandas as pd


def article_epu_index(symbol: str = "China") -> pd.DataFrame:
    """
    经济政策不确定性指数
    https://www.policyuncertainty.com/index.html
    :param symbol: 指定的国家名称, e.g. “China”
    :type symbol: str
    :return: 经济政策不确定性指数数据
    :rtype: pandas.DataFrame
    """
    # 切勿修改 http 否则会读取不到 csv 文件
    if symbol == "China New":
        symbol = "SCMP_China"
    if symbol == "China":
        symbol = "SCMP_China"
    if symbol == "USA":
        symbol = "US"
    if symbol == "Hong Kong":
        symbol = "HK"
        epu_df = pd.read_excel(
            io=f"http://www.policyuncertainty.com/media/{symbol}_EPU_Data_Annotated.xlsx",
            engine="openpyxl",
        )
        return epu_df
    if symbol in ["Germany", "France", "Italy"]:  # 欧洲
        symbol = "Europe"
    if symbol == "South Korea":
        symbol = "Korea"
    if symbol == "Spain New":
        symbol = "Spain"
    if symbol in ["Ireland", "Chile", "Colombia", "Netherlands", "Singapore", "Sweden"]:
        epu_df = pd.read_excel(
            io=f"http://www.policyuncertainty.com/media/{symbol}_Policy_Uncertainty_Data.xlsx",
            engine="openpyxl",
        )
        return epu_df
    if symbol == "Greece":
        epu_df = pd.read_excel(
            io=f"http://www.policyuncertainty.com/media/FKT_{symbol}_Policy_Uncertainty_Data.xlsx",
            engine="openpyxl",
        )
        return epu_df
    url = f"http://www.policyuncertainty.com/media/{symbol}_Policy_Uncertainty_Data.csv"
    epu_df = pd.read_csv(url)
    return epu_df


if __name__ == "__main__":
    article_epu_index_df = article_epu_index(symbol="China")
    print(article_epu_index_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/6/26 15:33
Desc: 英为财情-外汇-货币对历史数据
https://cn.investing.com/currencies/
https://cn.investing.com/currencies/eur-usd-historical-data
"""

import pandas as pd
import requests
from bs4 import BeautifulSoup
from akshare.utils.tqdm import get_tqdm


def currency_pair_map(symbol: str = "美元") -> pd.DataFrame:
    """
    指定货币的所有可获取货币对的数据
    https://cn.investing.com/currencies/cny-jmd
    :param symbol: 指定货币
    :type symbol: str
    :return: 指定货币的所有可获取货币对的数据
    :rtype: pandas.DataFrame
    """
    region_code = []
    region_name = []
    headers = {
        "Accept": "application/json, text/javascript, */*; q=0.01",
        # "Accept-Encoding": "gzip, deflate, br",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Connection": "keep-alive",
        "Host": "cn.investing.com",
        "Pragma": "no-cache",
        "Referer": "https://cn.investing.com/currencies/single-currency-crosses",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/79.0.3945.130 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }

    def has_data_sml_id_but_no_id(tag):
        return tag.has_attr("data-sml-id") and not tag.has_attr("title")

    tqdm = get_tqdm()
    for region_id in tqdm(["4", "1", "8", "7", "6"], leave=False):
        url = "https://cn.investing.com/currencies/Service/region"
        params = {"region_ID": region_id, "currency_ID": "false"}

        r = requests.get(url, params=params, headers=headers)
        soup = BeautifulSoup(r.text, features="lxml")
        region_code.extend(
            [
                item["continentid"] + "-" + region_id
                for item in soup.find_all(has_data_sml_id_but_no_id)
            ]
        )
        region_name.extend(
            [item.find("i").text for item in soup.find_all(has_data_sml_id_but_no_id)]
        )

    name_id_map = dict(zip(region_name, region_code))
    url = "https://cn.investing.com/currencies/Service/currency"
    params = {
        "region_ID": name_id_map[symbol].split("-")[1],
        "currency_ID": name_id_map[symbol].split("-")[0],
    }
    r = requests.get(url, params=params, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")

    temp_code = [item["href"].split("/")[-1] for item in soup.find_all("a")]  # need
    temp_name = [item["title"].replace(" ", "-") for item in soup.find_all("a")]
    temp_df = pd.DataFrame(data=[temp_name, temp_code], index=["name", "code"]).T
    return temp_df


if __name__ == "__main__":
    currency_pair_map_df = currency_pair_map(symbol="人民币")
    print(currency_pair_map_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/12/25 17:00
Desc: 财新网-财新数据通
https://cxdata.caixin.com/pc/
"""

import pandas as pd
import requests


def stock_news_main_cx() -> pd.DataFrame:
    """
    财新网-财新数据通
    https://cxdata.caixin.com/pc/
    :return: 特定时间表示的字典
    :rtype: pandas.DataFrame
    """
    url = "https://cxdata.caixin.com/api/dataplus/sjtPc/news"
    params = {
        "pageNum": "1",
        "pageSize": "100",
        "showLabels": "true",
    }
    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/143.0.0.0 Safari/537.36",
        "referer": "https://cxdata.caixin.com/index/newsTab?tab=latest"
    }
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["data"])
    temp_df = temp_df[["tag", "summary", "url"]]
    temp_df.columns = ["tag", "summary", "url"]
    temp_df.dropna(inplace=True)
    return temp_df


if __name__ == "__main__":
    stock_news_main_cx_df = stock_news_main_cx()
    print(stock_news_main_cx_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/2/24 18:33
Desc: 两网及退市
https://quote.eastmoney.com/center/gridlist.html#staq_net_board
"""

import pandas as pd
import requests


def stock_staq_net_stop() -> pd.DataFrame:
    """
    东方财富网-行情中心-沪深个股-两网及退市
    https://quote.eastmoney.com/center/gridlist.html#staq_net_board
    :return: 两网及退市
    :rtype: pandas.DataFrame
    """
    url = "https://5.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": "1",
        "pz": "50000",
        "po": "1",
        "np": "2",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "fid": "f3",
        "fs": "m:0 s:3",
        "fields": "f12,f14",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["diff"]).T
    temp_df.reset_index(inplace=True)
    temp_df["index"] = temp_df.index + 1
    temp_df.columns = ["序号", "代码", "名称"]
    return temp_df


if __name__ == "__main__":
    stock_staq_net_stop_df = stock_staq_net_stop()
    print(stock_staq_net_stop_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/9 22:00
Desc: 东方财富网-行情中心-期货市场-国际期货
https://quote.eastmoney.com/center/gridlist.html#futures_global
"""

import math
from typing import Optional

import pandas as pd
import requests

from akshare.utils.tqdm import get_tqdm


def __futures_global_hist_market_code(symbol: str = "HG00Y") -> Optional[int]:
    """
    东方财富网-行情中心-期货市场-国际期货-品种市场对照表
    https://quote.eastmoney.com/center/gridlist.html#futures_global
    :param symbol: HG00Y, 品种代码；可以通过 ak.futures_global_spot_em() 来获取所有可获取历史行情数据的品种代码
    :type symbol: str
    :return: 品种所属于的市场
    :rtype: str
    """
    # 提取品种代码（去掉年份和月份部分）
    base_symbol = ""
    i = 0
    while i < len(symbol) and not symbol[i].isdigit():
        base_symbol += symbol[i]
        i += 1
    # 如果代码中没有数字（异常情况），则返回整个代码作为基础品种代码
    if not base_symbol and i == len(symbol):
        base_symbol = symbol
    # 金属和贵金属品种 - 101
    if base_symbol in ["HG", "GC", "SI", "QI", "QO", "MGC", "LTH"]:
        return 101
    # 能源品种 - 102
    if base_symbol in ["CL", "NG", "RB", "HO", "PA", "PL", "QM"]:
        return 102
    # 农产品和金融品种 - 103
    if base_symbol in [
        "ZW",
        "ZM",
        "ZS",
        "ZC",
        "XC",
        "XK",
        "XW",
        "YM",
        "TY",
        "US",
        "EH",
        "ZL",
        "ZR",
        "ZO",
        "FV",
        "TU",
        "UL",
        "NQ",
        "ES",
    ]:
        return 103
    # 中国市场特有品种 - 104
    if base_symbol in ["TF", "RT", "CN"]:
        return 104
    # 软商品期货 - 108
    if base_symbol in ["SB", "CT", "SF"]:
        return 108
    # 特殊L开头品种 - 109
    if base_symbol in ["LCPT", "LZNT", "LALT", "LTNT", "LLDT", "LNKT"]:
        return 109
    # MPM开头品种 - 110
    if base_symbol == "MPM":
        return 110
    # 日本市场品种 - 111
    if base_symbol.startswith("J"):
        return 111
    # 单字母代码品种 - 112
    if base_symbol in ["M", "B", "G"]:
        return 112
    # 如果没有匹配到任何规则，返回一个默认值或者错误
    return None


def futures_global_spot_em() -> pd.DataFrame:
    """
    东方财富网-行情中心-期货市场-国际期货
    https://quote.eastmoney.com/center/gridlist.html#futures_global
    :return: 行情数据
    :rtype: pandas.DataFrame
    """
    url = "https://futsseapi.eastmoney.com/list/COMEX,NYMEX,COBOT,SGX,NYBOT,LME,MDEX,TOCOM,IPE"
    params = {
        "orderBy": "dm",
        "sort": "desc",
        "pageSize": "20",
        "pageIndex": "0",
        "token": "58b2fa8f54638b60b87d69b31969089c",
        "field": "dm,sc,name,p,zsjd,zde,zdf,f152,o,h,l,zjsj,vol,wp,np,ccl",
        "blockName": "callback",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_num = data_json["total"]
    total_page = math.ceil(total_num / 20) - 1
    tqdm = get_tqdm()
    big_df = pd.DataFrame()
    for page in tqdm(range(total_page), leave=False):
        params.update({"pageIndex": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["list"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df["index"] = big_df["index"] + 1
    big_df.rename(
        columns={
            "index": "序号",
            "np": "卖盘",
            "h": "最高",
            "dm": "代码",
            "zsjd": "-",
            "l": "最低",
            "ccl": "持仓量",
            "o": "今开",
            "p": "最新价",
            "sc": "-",
            "vol": "成交量",
            "name": "名称",
            "wp": "买盘",
            "zde": "涨跌额",
            "zdf": "涨跌幅",
            "zjsj": "昨结",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "序号",
            "代码",
            "名称",
            "最新价",
            "涨跌额",
            "涨跌幅",
            "今开",
            "最高",
            "最低",
            "昨结",
            "成交量",
            "买盘",
            "卖盘",
            "持仓量",
        ]
    ]
    big_df["最新价"] = pd.to_numeric(big_df["最新价"], errors="coerce")
    big_df["涨跌额"] = pd.to_numeric(big_df["涨跌额"], errors="coerce")
    big_df["涨跌幅"] = pd.to_numeric(big_df["涨跌幅"], errors="coerce")
    big_df["今开"] = pd.to_numeric(big_df["今开"], errors="coerce")
    big_df["最高"] = pd.to_numeric(big_df["最高"], errors="coerce")
    big_df["最低"] = pd.to_numeric(big_df["最低"], errors="coerce")
    big_df["昨结"] = pd.to_numeric(big_df["昨结"], errors="coerce")
    big_df["成交量"] = pd.to_numeric(big_df["成交量"], errors="coerce")
    big_df["买盘"] = pd.to_numeric(big_df["买盘"], errors="coerce")
    big_df["卖盘"] = pd.to_numeric(big_df["卖盘"], errors="coerce")
    big_df["持仓量"] = pd.to_numeric(big_df["持仓量"], errors="coerce")
    return big_df


def futures_global_hist_em(symbol: str = "HG00Y") -> pd.DataFrame:
    """
    东方财富网-行情中心-期货市场-国际期货-历史行情数据
    https://quote.eastmoney.com/globalfuture/HG25J.html
    :param symbol: 品种代码；可以通过 ak.futures_global_spot_em() 来获取所有可获取历史行情数据的品种代码
    :type symbol: str
    :return: 历史行情数据
    :rtype: pandas.DataFrame
    """
    url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"
    market_code = __futures_global_hist_market_code(symbol)
    params = {
        "secid": f"{market_code}.{symbol}",
        "klt": "101",
        "fqt": "1",
        "lmt": "6600",
        "end": "20500000",
        "iscca": "1",
        "fields1": "f1,f2,f3,f4,f5,f6,f7,f8",
        "fields2": "f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61,f62,f63,f64",
        "ut": "f057cbcbce2a86e2866ab8877db1d059",
        "forcect": "1",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
    temp_df["code"] = data_json["data"]["code"]
    temp_df["name"] = data_json["data"]["name"]
    temp_df.columns = [
        "日期",
        "开盘",
        "最新价",
        "最高",
        "最低",
        "总量",
        "-",
        "-",
        "涨幅",
        "-",
        "-",
        "-",
        "持仓",
        "日增",
        "代码",
        "名称",
    ]
    temp_df = temp_df[
        [
            "日期",
            "代码",
            "名称",
            "开盘",
            "最新价",
            "最高",
            "最低",
            "总量",
            "涨幅",
            "持仓",
            "日增",
        ]
    ]
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df["开盘"] = pd.to_numeric(temp_df["开盘"], errors="coerce")
    temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce")
    temp_df["最高"] = pd.to_numeric(temp_df["最高"], errors="coerce")
    temp_df["最低"] = pd.to_numeric(temp_df["最低"], errors="coerce")
    temp_df["总量"] = pd.to_numeric(temp_df["总量"], errors="coerce")
    temp_df["涨幅"] = pd.to_numeric(temp_df["涨幅"], errors="coerce")
    temp_df["日增"] = pd.to_numeric(temp_df["日增"], errors="coerce")
    # 日增修复为有符号32位整数值
    unsigned_max, signed_max = (2 ** 32) - 1, (2 ** 31) - 1
    mask = temp_df["日增"] > signed_max
    temp_df.loc[mask, "日增"] = temp_df.loc[mask, "日增"] - (unsigned_max + 1)
    return temp_df


if __name__ == "__main__":
    futures_global_spot_em_df = futures_global_spot_em()
    print(futures_global_spot_em_df)

    futures_global_hist_em_df = futures_global_hist_em(symbol="HG00Y")
    print(futures_global_hist_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/10/29 21:00
Desc: AKShare's PYPI info file
"""

import ast
import re

import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()


def get_version_string() -> str:
    """
    get the version of akshare
    :return: version number
    :rtype: str, e.g. '0.6.24'
    """
    with open("akshare/__init__.py", "rb") as _f:
        version_line = re.search(
            pattern=r"__version__\s+=\s+(.*)", string=_f.read().decode("utf-8")
        ).group(1)
        return str(ast.literal_eval(version_line))


setuptools.setup(
    name="akshare",
    version=get_version_string(),
    author="AKFamily",
    author_email="albertandking@gmail.com",
    license="MIT",
    description="AKShare is an elegant and simple financial data interface library for Python, built for human beings!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/akfamily/akshare",
    packages=setuptools.find_packages(),
    install_requires=[
        "aiohttp>=3.11.13",
        "beautifulsoup4>=4.9.1",
        "lxml>=4.2.1",
        "pandas>=0.25",
        "requests>=2.22.0",
        "curl_cffi>=0.13.0",
        "html5lib>=1.0.1",
        "xlrd>=1.2.0",
        "urllib3>=1.25.8",
        "tqdm>=4.43.0",
        "openpyxl>=3.0.3",
        "jsonpath>=0.82",
        "tabulate>=0.8.6",
        "decorator>=4.4.2",
        "nest_asyncio>=1.6.0",
        "mini-racer>=0.12.4;platform_system!='Linux'",
        "py-mini-racer>=0.6.0;platform_system=='Linux'",
        "akracer>=0.0.13;platform_system=='Linux'",
    ],
    extras_require={
        # 这些是额外的依赖集合，可以通过 'pip install akshare[full]' 安装
        "full": [
            "akqmt",
        ],
        # 这些是额外的依赖集合，可以通过 'pip install akshare[qmt]' 安装
        "qmt": [
            "akqmt",
        ],
    },
    package_data={"": ["*.py", "*.json", "*.pk", "*.js", "*.zip"]},
    keywords=[
        "stock",
        "option",
        "futures",
        "fund",
        "bond",
        "index",
        "air",
        "finance",
        "spider",
        "quant",
        "quantitative",
        "investment",
        "trading",
        "algotrading",
        "data",
    ],
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/3/5 12:55
Desc: 上登债券信息网-债券成交概览
http://bond.sse.com.cn/data/statistics/overview/turnover/
"""

from io import BytesIO

import pandas as pd
import requests


def bond_cash_summary_sse(date: str = "20210111") -> pd.DataFrame:
    """
    上登债券信息网-市场数据-市场统计-市场概览-债券现券市场概览
    http://bond.sse.com.cn/data/statistics/overview/bondow/
    :param date: 指定日期
    :type date: str
    :return: 债券成交概览
    :rtype: pandas.DataFrame
    """
    url = "http://query.sse.com.cn/commonExcelDd.do"
    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
        "Referer": "http://bond.sse.com.cn/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88 Safari/537.36",
    }
    params = {
        "sqlId": "COMMON_SSEBOND_SCSJ_SCTJ_SCGL_ZQXQSCGL_CX_L",
        "TRADE_DATE": f"{date[:4]}-{date[4:6]}-{date[6:]}",
    }
    r = requests.get(url, params=params, headers=headers)
    temp_df = pd.read_excel(BytesIO(r.content), engine="xlrd")
    temp_df.columns = [
        "债券现货",
        "托管只数",
        "托管市值",
        "托管面值",
        "数据日期",
    ]
    temp_df["托管只数"] = pd.to_numeric(temp_df["托管只数"])
    temp_df["托管市值"] = pd.to_numeric(temp_df["托管市值"])
    temp_df["托管面值"] = pd.to_numeric(temp_df["托管面值"])
    temp_df["数据日期"] = pd.to_datetime(temp_df["数据日期"]).dt.date
    return temp_df


def bond_deal_summary_sse(date: str = "20210104") -> pd.DataFrame:
    """
    上登债券信息网-市场数据-市场统计-市场概览-债券成交概览
    http://bond.sse.com.cn/data/statistics/overview/turnover/
    :param date: 指定日期
    :type date: str
    :return: 债券成交概览
    :rtype: pandas.DataFrame
    """
    url = "http://query.sse.com.cn/commonExcelDd.do"
    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
        "Referer": "http://bond.sse.com.cn/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88 Safari/537.36",
    }
    params = {
        "sqlId": "COMMON_SSEBOND_SCSJ_SCTJ_SCGL_ZQCJGL_CX_L",
        "TRADE_DATE": f"{date[:4]}-{date[4:6]}-{date[6:]}",
    }
    r = requests.get(url, params=params, headers=headers)
    temp_df = pd.read_excel(BytesIO(r.content))
    temp_df.columns = [
        "债券类型",
        "当日成交笔数",
        "当日成交金额",
        "当年成交笔数",
        "当年成交金额",
        "数据日期",
    ]
    temp_df["当日成交笔数"] = pd.to_numeric(temp_df["当日成交笔数"])
    temp_df["当日成交金额"] = pd.to_numeric(temp_df["当日成交金额"])
    temp_df["当年成交笔数"] = pd.to_numeric(temp_df["当年成交笔数"])
    temp_df["当年成交金额"] = pd.to_numeric(temp_df["当年成交金额"])
    temp_df["数据日期"] = pd.to_datetime(temp_df["数据日期"]).dt.date
    return temp_df


if __name__ == "__main__":
    bond_cash_summary_sse_df = bond_cash_summary_sse(date="20210111")
    print(bond_cash_summary_sse_df)

    bond_summary_sse_df = bond_deal_summary_sse(date="20210111")
    print(bond_summary_sse_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/6/13 22:05
Desc: 柯桥时尚指数
http://ss.kqindex.cn:9559/rinder_web_kqsszs/index/index_page.do
"""

import pandas as pd
import requests


def index_kq_fashion(symbol: str = "时尚创意指数") -> pd.DataFrame:
    """
    柯桥时尚指数
    http://ss.kqindex.cn:9559/rinder_web_kqsszs/index/index_page.do
    :param symbol: choice of {'柯桥时尚指数', '时尚创意指数', '时尚设计人才数', '新花型推出数', '创意产品成交数', '创意企业数量', '时尚活跃度指数', '电商运行数', '时尚平台拓展数', '新产品销售额占比', '企业合作占比', '品牌传播费用', '时尚推广度指数', '国际交流合作次数', '企业参展次数', '外商驻点数量变化', '时尚评价指数'}
    :type symbol: str
    :return: 柯桥时尚指数及其子项数据
    :rtype: pandas.DataFrame
    """
    url = "http://api.idx365.com/index/project/34/data"
    symbol_map = {
        "柯桥时尚指数": "root",
        "时尚创意指数": "01",
        "时尚设计人才数": "0101",
        "新花型推出数": "0102",
        "创意产品成交数": "0103",
        "创意企业数量": "0104",
        "时尚活跃度指数": "02",
        "电商运行数": "0201",
        "时尚平台拓展数": "0201",
        "新产品销售额占比": "0201",
        "企业合作占比": "0201",
        "品牌传播费用": "0201",
        "时尚推广度指数": "03",
        "国际交流合作次数": "0301",
        "企业参展次数": "0302",
        "外商驻点数量变化": "0302",
        "时尚评价指数": "04",
    }
    params = {"structCode": symbol_map[symbol]}
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df.rename(
        columns={
            "id": "_",
            "indexValue": "指数",
            "lastValue": "_",
            "projId": "_",
            "publishTime": "日期",
            "sameValue": "_",
            "stageId": "_",
            "structCode": "_",
            "structName": "_",
            "version": "_",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "日期",
            "指数",
        ]
    ]
    temp_df["日期"] = pd.to_datetime(temp_df["日期"]).dt.date
    temp_df.sort_values("日期", inplace=True)
    temp_df["涨跌值"] = temp_df["指数"].diff()
    temp_df["涨跌幅"] = temp_df["指数"].pct_change()
    temp_df.sort_values("日期", ascending=True, inplace=True, ignore_index=True)
    return temp_df


if __name__ == "__main__":
    for item in [
        "柯桥时尚指数",
        "时尚创意指数",
        "时尚设计人才数",
        "新花型推出数",
        "创意产品成交数",
        "创意企业数量",
        "时尚活跃度指数",
        "电商运行数",
        "时尚平台拓展数",
        "新产品销售额占比",
        "企业合作占比",
        "品牌传播费用",
        "时尚推广度指数",
        "国际交流合作次数",
        "企业参展次数",
        "外商驻点数量变化",
        "时尚评价指数",
    ]:
        index_kq_fashion_df = index_kq_fashion(symbol=item)
        print(item)
        print(index_kq_fashion_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/10 18:00
Desc: 东财财富-日内分时数据
https://quote.eastmoney.com/f1.html?newcode=0.000001
"""

import json

import pandas as pd
import requests


def __event_stream(url, params):
    # 使用 stream=True 参数来启用流式请求
    response = requests.get(url, params=params, stream=True)
    event_data = ""

    for line in response.iter_lines():
        # 过滤掉保持连接的空行
        if line:
            event_data += line.decode() + "\n"
        elif event_data:
            yield event_data
            event_data = ""


def stock_intraday_em(symbol: str = "000001") -> pd.DataFrame:
    """
    东方财富-分时数据
    https://quote.eastmoney.com/f1.html?newcode=0.000001
    :param symbol: 股票代码
    :type symbol: str
    :return: 分时数据
    :rtype: pandas.DataFrame
    """
    market_code = 1 if symbol.startswith("6") else 0
    url = "https://70.push2.eastmoney.com/api/qt/stock/details/sse"
    params = {
        "fields1": "f1,f2,f3,f4",
        "fields2": "f51,f52,f53,f54,f55",
        "mpi": "2000",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "pos": "-0",
        "secid": f"{market_code}.{symbol}",
        "wbp2u": "|0|0|0|web",
    }

    big_df = pd.DataFrame()  # 创建一个空的 DataFrame

    for event in __event_stream(url, params):
        # 从每个事件的数据行中删除 "data: "，然后解析 JSON
        event_json = json.loads(event.replace("data: ", ""))
        # 将 JSON 数据转换为 DataFrame，然后添加到主 DataFrame 中
        temp_df = pd.DataFrame(
            [item.split(",") for item in event_json["data"]["details"]]
        )
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
        break

    big_df.columns = ["时间", "成交价", "手数", "-", "买卖盘性质"]
    big_df["买卖盘性质"] = big_df["买卖盘性质"].map(
        {"2": "买盘", "1": "卖盘", "4": "中性盘"}
    )
    big_df = big_df[["时间", "成交价", "手数", "买卖盘性质"]]
    big_df["成交价"] = pd.to_numeric(big_df["成交价"], errors="coerce")
    big_df["手数"] = pd.to_numeric(big_df["手数"], errors="coerce")
    return big_df


if __name__ == "__main__":
    stock_intraday_em_df = stock_intraday_em(symbol="000001")
    print(stock_intraday_em_df)
